@@ -134,12 +134,12 @@ public:
     save_cont(do_nothing), sc(options), state(sc), do_savedicts(true),
     word(0), mis_end(0), backup_saved(false), changed(false) 
   {
-    if (options.lookup("dict-host").size())
-      if (options.lookup("dict-port").empty())
-	dc.setHost(options.lookup("dict-host").c_str());
+    if (options.have("dict-host"))
+      if (!options.have("dict-port"))
+	dc.setHost(options.retrieve("dict-host").c_str());
       else
-	dc.setHost(options.lookup("dict-host").c_str(),
-		   atoi(options.lookup("dict-port").c_str()));
+	dc.setHost(options.retrieve("dict-host").c_str(),
+		   options.retrieve_int("dict-port"));
   }
   
   ~AspellCheck() {if (do_savedicts) sc.save_all_wls();}
@@ -584,7 +584,7 @@ int AspellCheck::clear() {
 
 AspellCheck::problem AspellCheck::check_file(string &fn) {
   if (fn == "<none>") 
-    fn = options["infile"];
+    fn = options.retrieve("infile");
   if (fn.size() == 0 || *(fn.end()-1) == '/')
     return no_file;
   ifstream in(fn.c_str());
@@ -596,7 +596,7 @@ AspellCheck::problem AspellCheck::check_file(string &fn) {
 }
 
 void AspellCheck::proc_file_name(string &fn) {
-  options.replace("infile", fn);
+  options.replace("infile", fn.c_str());
   string::size_type last_slash = fn.rfind('/');
   last_slash = last_slash == string::npos ? 0 : last_slash + 1;
   file_name = fn.substr(last_slash);
@@ -787,12 +787,12 @@ void AspellCheck::open_cancel() {
 }
 
 int AspellCheck::save() {
-  if (options["infile"].size()) {
+  if (options.have("infile")) {
     if (!backup_saved) {
-      string backup_name = options["infile"] + ".bak";
-      rename(options["infile"].c_str(), backup_name.c_str());
+      string backup_name = options.retrieve("infile") + ".bak";
+      rename(options.retrieve("infile").c_str(), backup_name.c_str());
     }
-    ofstream out(options["infile"].c_str());
+    ofstream out(options.retrieve("infile").c_str());
     GtkTextIterator i(GTK_TEXT(text)), e(GTK_TEXT(text)); e.go_end();
     for (; i != e; ++i) {
       out.put(*i);
@@ -810,9 +810,9 @@ void AspellCheck::save_as() {
     //
   } else {
     file_save =  gtk_file_selection_new("Save As");
-    if (options["infile"].size())
+    if (options.have("infile"))
       gtk_file_selection_set_filename(GTK_FILE_SELECTION(file_save),
-				      options["infile"].c_str());
+				      options.retrieve("infile").c_str());
     gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(file_save)->ok_button),
 		       "clicked", GTK_SIGNAL_FUNC(save_ok_clicked), 
 		       (gpointer)this);
@@ -1043,9 +1043,9 @@ void options_act(poptContext, poptCallbackReason,
 		 const poptOption *, const char *, void *);
 
 static const KeyInfo extra[] = {
-  {"dict-host", KeyInfo::String, "", "Host name of DICT server"},
-  {"dict-port", KeyInfo::Int   , "", "Port number of DICT server"},
-  {"infile",    KeyInfo::String, "", "File name to check."}
+  {"dict-host", KeyInfoString, "", "Host name of DICT server"},
+  {"dict-port", KeyInfoInt   , "", "Port number of DICT server"},
+  {"infile",    KeyInfoString, "", "File name to check."}
 };
 
 int main (int argc, char *argv[]) {
@@ -1056,14 +1056,14 @@ int main (int argc, char *argv[]) {
   unsigned int popt_opts_size = 2;
   unsigned int popt_strs_size = 0;
 
-  Emulation<const KeyInfo *> els = options.possible_elements();
+  ConfigData::PossibleElementsEmul els = options.possible_elements();
   const KeyInfo * k;
   while (k = els.next(), k) {
     if (k->desc == 0) continue;
-    if (k->type == KeyInfo::Bool) {
+    if (k->type == KeyInfoBool) {
       popt_opts_size += 2;
       popt_strs_size += 6 + strlen(k->name);
-    } else if (k->type == KeyInfo::List) {
+    } else if (k->type == KeyInfoList) {
       popt_opts_size += 2;
       popt_strs_size += 2*(5 + strlen(k->name));
     } else {
@@ -1081,7 +1081,7 @@ int main (int argc, char *argv[]) {
   els = options.possible_elements();
   while (k = els.next(), k) {
     if (k->desc == 0) continue;
-    if (k->type == KeyInfo::Bool) {
+    if (k->type == KeyInfoBool) {
       i->argInfo  = POPT_ARG_NONE;
       i->longName = k->name;
       i->descrip  = k->desc;
@@ -1092,7 +1092,7 @@ int main (int argc, char *argv[]) {
       strcpy(j, k->name); j += strlen(j) + 1;
       i->descrip  = NULL;
       ++i;
-    } else if (k->type == KeyInfo::List) {
+    } else if (k->type == KeyInfoList) {
       i->argInfo = POPT_ARG_NONE;
       i->longName = j; 
       strcpy(j, "add-");  j += 4;
@@ -1109,7 +1109,7 @@ int main (int argc, char *argv[]) {
       i->longName =  k->name;
       i->argInfo  =  POPT_ARG_STRING;
       i->descrip  =  k->desc;
-      i->argDescrip = k->type == KeyInfo::Int  ? "<int>" : "<str>";
+      i->argDescrip = k->type == KeyInfoInt  ? "<int>" : "<str>";
       ++i;
     }
   }
@@ -1118,8 +1118,10 @@ int main (int argc, char *argv[]) {
   gnome_init_with_popt_table("gaspell", "0.0" , argc, argv, popt_opts, 
 			     0, &pcontext);
   
-  if (poptPeekArg(pcontext))
-    options.insert("infile", poptGetArg(pcontext));
+  if (poptPeekArg(pcontext)) {
+    if (!options.have("infile"))
+      options.replace("infile", poptGetArg(pcontext));
+  }
   
   AspellApp * app;
   try {
